package Bencher::Scenarios::IPCRun;

our $DATE = '2017-01-25'; # DATE
our $VERSION = '0.002'; # VERSION

1;
# ABSTRACT: Scenarios to benchmark IPC::Run

__END__

=pod

=encoding UTF-8

=head1 NAME

Bencher::Scenarios::IPCRun - Scenarios to benchmark IPC::Run

=head1 VERSION

This document describes version 0.002 of Bencher::Scenarios::IPCRun (from Perl distribution Bencher-Scenarios-IPCRun), released on 2017-01-25.

=head1 TODO

Show where IPC::Run is slow.

run_overhead still sometimes exit.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Bencher-Scenarios-IPCRun>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Bencher-Scenarios-IPCRun>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Bencher-Scenarios-IPCRun>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2017 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
